==> php-residence-mod-de_0.3.3.tar.gz: de/costi.php <==
<?php

switch ($messaggio) {

case "Si deve inserire un nome per l' entrata":	$messaggio = "Sie m&uuml;ssen einen Grund f&uuml;r den Zahlungseingang angeben"; break;
case "Si deve inserire il valore dell' entrata":	$messaggio = "Sie m&uuml;ssen einen Wert f&uuml;r den Zahlungseingang angeben"; break;
case "L' entrata  stata inserita":  		$messaggio = "Zahlungseingang eingetragen"; break;
case "Si deve inserire un nome per la spesa":	$messaggio = "Sie m&uuml;ssen einen Grund f&uuml;r die Zahlung angeben"; break;
case "Si deve inserire il valore della spesa":	$messaggio = "Sie m&uuml;ssen einen Wert f&uuml;r die Zahlung angeben"; break;
case "La spesa  stata inserita":  		$messaggio = "Zahlung wurde eingetragen"; break;
case "Inserisci i costi di gestione per l'anno":	$messaggio = "Zahlungsausg&auml;nge eingeben f&uuml;r das Jahr"; break;
case "Natura spesa":  				$messaggio = "Zahlungsgrund"; break;
case "Importo":  				$messaggio = "Betrag"; break;
case "Persona che inserisce":  			$messaggio = "Eintragende Person"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Inserisci la spesa":  			$messaggio = "Zahlung eintragen"; break;
case "Inserisci le entrate in cassa per l'anno":	$messaggio = "Zahlungseing&auml;nge eingeben f&uuml;r das Jahr"; break;
case "Natura entrata":  			$messaggio = "Grund f&uuml;r den Eingang"; break;
case "Inserisci l' entrata":  			$messaggio = "Zahlungseingang eingeben"; break;
case "Sottrai l'importo dal totale delle prenotazioni":	$messaggio = "Betrag von der Gesamtsumme der Reservierungen abziehen"; break;
case "Visualizza la tabella con tutte le spese e le entrate":	$messaggio = "Tabelle mit allen Zahlungseing&auml;ngen und Zahlungsausg&auml;ngen anzeigen"; break;
case "Torna al men principale":  		$messaggio = "Zur&uuml;ck zum Hauptmen&uuml;"; break;
case "Il valore dell' entrata  sbagliato":  	$messaggio = "Der Wert des Zahlungseinganges ist falsch"; break;
case "Il valore della spesa  sbagliato":  	$messaggio = "Der Wert des Zahlungsausganges ist falsch"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence-mod-de_1.1.1-1.tar.gz: de/costi.php <==
<?php

switch ($messaggio) {

case "Si deve inserire un nome per l' entrata":	$messaggio = "Sie m&uuml;ssen einen Grund f&uuml;r den Zahlungseingang angeben"; break;
case "Si deve inserire il valore dell' entrata":	$messaggio = "Sie m&uuml;ssen einen Wert f&uuml;r den Zahlungseingang angeben"; break;
case "L' entrata è stata inserita":  		$messaggio = "Zahlungseingang eingetragen"; break;
case "Si deve inserire un nome per la spesa":	$messaggio = "Sie m&uuml;ssen einen Grund f&uuml;r die Zahlung angeben"; break;
case "Si deve inserire il valore della spesa":	$messaggio = "Sie m&uuml;ssen einen Wert f&uuml;r die Zahlung angeben"; break;
case "La spesa è stata inserita":  		$messaggio = "Zahlung wurde eingetragen"; break;
case "Inserisci i costi di gestione per l'anno":	$messaggio = "Zahlungsausg&auml;nge eingeben f&uuml;r das Jahr"; break;
case "Natura spesa":  				$messaggio = "Zahlungsgrund"; break;
case "Importo":  				$messaggio = "Betrag"; break;
case "Persona che inserisce":  			$messaggio = "Eintragende Person"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Inserisci la spesa":  			$messaggio = "Zahlung eintragen"; break;
case "Inserisci le entrate in cassa per l'anno":	$messaggio = "Zahlungseing&auml;nge eingeben f&uuml;r das Jahr"; break;
case "Natura entrata":  			$messaggio = "Grund f&uuml;r den Eingang"; break;
case "Inserisci l' entrata":  			$messaggio = "Zahlungseingang eingeben"; break;
case "Sottrai l'importo dal totale delle prenotazioni":	$messaggio = "Betrag von der Gesamtsumme der Reservierungen abziehen"; break;
case "Visualizza la tabella con tutte le spese e le entrate":	$messaggio = "Tabelle mit allen Zahlungseing&auml;ngen und Zahlungsausg&auml;ngen anzeigen"; break;
case "Torna al menù principale":  		$messaggio = "Zur&uuml;ck zum Hauptmen&uuml;"; break;
case "Il valore dell' entrata è sbagliato":  	$messaggio = "Der Wert des Zahlungseinganges ist falsch"; break;
case "Il valore della spesa è sbagliato":  	$messaggio = "Der Wert des Zahlungsausganges ist falsch"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
